@@ -4,17 +4,16 @@
   Foundation.libs.topbar = {
     name : 'topbar',
 
-    version: '5.5.0',
+    version: '5.1.0',
 
     settings : {
       index : 0,
       sticky_class : 'sticky',
       custom_back_text: true,
       back_text: 'Back',
-      mobile_show_parent_link: true,
       is_hover: true,
-      scrolltop : true, // jump to top when sticky nav menu toggle is clicked
-      sticky_on : 'all'
+      mobile_show_parent_link: false,
+      scrolltop : true // jump to top when sticky nav menu toggle is clicked
     },
 
     init : function (section, method, options) {
@@ -26,12 +25,15 @@
       this.bindings(method, options);
 
       self.S('[' + this.attr_name() + ']', this.scope).each(function () {
-        var topbar = $(this),
+        var topbar = self.S(this),
             settings = topbar.data(self.attr_name(true) + '-init'),
-            section = self.S('section, .top-bar-section', this);
+            section = self.S('section', this),
+            titlebar = $('> ul', this).first();
+
         topbar.data('index', 0);
+
         var topbarContainer = topbar.parent();
-        if (topbarContainer.hasClass('fixed') || self.is_sticky(topbar, topbarContainer, settings) ) {
+        if(topbarContainer.hasClass('fixed') || topbarContainer.hasClass(settings.sticky_class)) {
           self.settings.sticky_class = settings.sticky_class;
           self.settings.sticky_topbar = topbar;
           topbar.data('height', topbarContainer.outerHeight());
@@ -40,9 +42,7 @@
           topbar.data('height', topbar.outerHeight());
         }
 
-        if (!settings.assembled) {
-          self.assemble(topbar);
-        }
+        if (!settings.assembled) self.assemble(topbar);
 
         if (settings.is_hover) {
           self.S('.has-dropdown', topbar).addClass('not-click');
@@ -60,41 +60,18 @@
 
     },
 
-    is_sticky: function (topbar, topbarContainer, settings) {
-      var sticky = topbarContainer.hasClass(settings.sticky_class);
-
-      if (sticky && settings.sticky_on === 'all') {
-        return true;
-      } else if (sticky && this.small() && settings.sticky_on === 'small') {
-        return (matchMedia(Foundation.media_queries.small).matches && !matchMedia(Foundation.media_queries.medium).matches &&
-            !matchMedia(Foundation.media_queries.large).matches);
-        //return true;
-      } else if (sticky && this.medium() && settings.sticky_on === 'medium') {
-        return (matchMedia(Foundation.media_queries.small).matches && matchMedia(Foundation.media_queries.medium).matches &&
-            !matchMedia(Foundation.media_queries.large).matches);
-        //return true;
-      } else if(sticky && this.large() && settings.sticky_on === 'large') {
-        return (matchMedia(Foundation.media_queries.small).matches && matchMedia(Foundation.media_queries.medium).matches &&
-            matchMedia(Foundation.media_queries.large).matches);
-        //return true;
-      }
-
-      return false;
-    },
-
     toggle: function (toggleEl) {
-      var self = this,
-          topbar;
+      var self = this;
 
       if (toggleEl) {
-        topbar = self.S(toggleEl).closest('[' + this.attr_name() + ']');
+        var topbar = self.S(toggleEl).closest('[' + this.attr_name() + ']');
       } else {
-        topbar = self.S('[' + this.attr_name() + ']');
+        var topbar = self.S('[' + this.attr_name() + ']');
       }
 
       var settings = topbar.data(this.attr_name(true) + '-init');
 
-      var section = self.S('section, .top-bar-section', topbar);
+      var section = self.S('section, .section', topbar);
 
       if (self.breakpoint()) {
         if (!self.rtl) {
@@ -128,15 +105,15 @@
 
             window.scrollTo(0,0);
           } else {
-            topbar.parent().removeClass('expanded');
+              topbar.parent().removeClass('expanded');
           }
         }
       } else {
-        if (self.is_sticky(topbar, topbar.parent(), settings)) {
+        if(topbar.parent().hasClass(self.settings.sticky_class)) {
           topbar.parent().addClass('fixed');
         }
 
-        if (topbar.parent().hasClass('fixed')) {
+        if(topbar.parent().hasClass('fixed')) {
           if (!topbar.hasClass('expanded')) {
             topbar.removeClass('fixed');
             topbar.parent().removeClass('expanded');
@@ -162,13 +139,6 @@
           e.preventDefault();
           self.toggle(this);
         })
-        .on('click.fndtn.topbar','.top-bar .top-bar-section li a[href^="#"],[' + this.attr_name() + '] .top-bar-section li a[href^="#"]',function (e) {
-            var li = $(this).closest('li');
-            if(self.breakpoint() && !li.hasClass('back') && !li.hasClass('has-dropdown'))
-            {
-            self.toggle();
-            }
-        })
         .on('click.fndtn.topbar', '[' + this.attr_name() + '] li.has-dropdown', function (e) {
           var li = S(this),
               target = S(e.target),
@@ -196,8 +166,6 @@
           } else {
             li.addClass('hover');
 
-            $(li).siblings().removeClass('hover');
-
             if (target[0].nodeName === 'A' && target.parent().hasClass('has-dropdown')) {
               e.preventDefault();
             }
@@ -210,7 +178,7 @@
 
             var $this = S(this),
                 topbar = $this.closest('[' + self.attr_name() + ']'),
-                section = topbar.find('section, .top-bar-section'),
+                section = topbar.find('section, .section'),
                 dropdownHeight = $this.next('.dropdown').outerHeight(),
                 $selectedLi = $this.closest('li');
 
@@ -228,22 +196,19 @@
             topbar.css('height', $this.siblings('ul').outerHeight(true) + topbar.data('height'));
           }
         });
+      
+      S(window).off('.topbar').on('resize.fndtn.topbar', self.throttle(function () {
+        self.resize.call(self);
+      }, 50)).trigger('resize');
 
-      S(window).off('.topbar').on('resize.fndtn.topbar', self.throttle(function() {
-          self.resize.call(self);
-      }, 50)).trigger('resize').trigger('resize.fndtn.topbar').load(function(){
-          // Ensure that the offset is calculated after all of the pages resources have loaded
-          S(this).trigger('resize.fndtn.topbar');
-      });
-
-      S('body').off('.topbar').on('click.fndtn.topbar', function (e) {
+      S('body').off('.topbar').on('click.fndtn.topbar touchstart.fndtn.topbar', function (e) {
         var parent = S(e.target).closest('li').closest('li.hover');
 
         if (parent.length > 0) {
           return;
         }
 
-        S('[' + self.attr_name() + '] li.hover').removeClass('hover');
+        S('[' + self.attr_name() + '] li').removeClass('hover');
       });
 
       // Go up a level on Click
@@ -252,7 +217,7 @@
 
         var $this = S(this),
             topbar = $this.closest('[' + self.attr_name() + ']'),
-            section = topbar.find('section, .top-bar-section'),
+            section = topbar.find('section, .section'),
             settings = topbar.data(self.attr_name(true) + '-init'),
             $movedLi = $this.closest('li.moved'),
             $previousLevelUl = $movedLi.parent();
@@ -277,15 +242,6 @@
           $movedLi.removeClass('moved');
         }, 300);
       });
-
-      // Show dropdown menus when their items are focused
-      S(this.scope).find('.dropdown a')
-        .focus(function() {
-          $(this).parents('.has-dropdown').addClass('hover');
-        })
-        .blur(function() {
-          $(this).parents('.has-dropdown').removeClass('hover');
-        });
     },
 
     resize : function () {
@@ -310,7 +266,7 @@
             }
         }
 
-        if(self.is_sticky(topbar, stickyContainer, settings)) {
+        if(stickyContainer.length > 0) {
           if(stickyContainer.hasClass('fixed')) {
             // Remove the fixed to allow for correct calculation of the offset.
             stickyContainer.removeClass('fixed');
@@ -335,22 +291,11 @@
       return !matchMedia(Foundation.media_queries['topbar']).matches;
     },
 
-    small : function () {
-      return matchMedia(Foundation.media_queries['small']).matches;
-    },
-
-    medium : function () {
-      return matchMedia(Foundation.media_queries['medium']).matches;
-    },
-
-    large : function () {
-      return matchMedia(Foundation.media_queries['large']).matches;
-    },
-
     assemble : function (topbar) {
       var self = this,
           settings = topbar.data(this.attr_name(true) + '-init'),
-          section = self.S('section, .top-bar-section', topbar);
+          section = self.S('section', topbar),
+          titlebar = $('> ul', topbar).first();
 
       // Pull element out of the DOM for manipulation
       section.detach();
@@ -358,18 +303,15 @@
       self.S('.has-dropdown>a', section).each(function () {
         var $link = self.S(this),
             $dropdown = $link.siblings('.dropdown'),
-            url = $link.attr('href'),
-            $titleLi;
-
+            url = $link.attr('href');
 
         if (!$dropdown.find('.title.back').length) {
-
-          if (settings.mobile_show_parent_link == true && url) {
-            $titleLi = $('<li class="title back js-generated"><h5><a href="javascript:void(0)"></a></h5></li><li class="parent-link show-for-small-only"><a class="parent-link js-generated" href="' + url + '">' + $link.html() +'</a></li>');
+          if (settings.mobile_show_parent_link && url && url.length > 1) {
+            var $titleLi = $('<li class="title back js-generated"><h5><a href="javascript:void(0)"></a></h5></li><li><a class="parent-link js-generated" href="' + url + '">' + $link.text() +'</a></li>');
           } else {
-            $titleLi = $('<li class="title back js-generated"><h5><a href="javascript:void(0)"></a></h5>');
+            var $titleLi = $('<li class="title back js-generated"><h5><a href="javascript:void(0)"></a></h5></li>');
           }
-
+  
           // Copy link to subnav
           if (settings.custom_back_text == true) {
             $('h5>a', $titleLi).html(settings.back_text);
@@ -397,15 +339,14 @@
       var total = 0,
           self = this;
 
-      $('> li', ul).each(function () {
-        total += self.S(this).outerHeight(true);
-      });
+      $('> li', ul).each(function () { total += self.S(this).outerHeight(true); });
 
       return total;
     },
 
     sticky : function () {
-      var self = this;
+      var $window = this.S(window),
+          self = this;
 
       this.S(window).on('scroll', function() {
         self.update_sticky_positioning();
@@ -417,7 +358,8 @@
           $window = this.S(window),
           self = this;
 
-      if (self.settings.sticky_topbar && self.is_sticky(this.settings.sticky_topbar,this.settings.sticky_topbar.parent(), this.settings)) {
+
+      if (self.S(klass).length > 0) {
         var distance = this.settings.sticky_topbar.data('stickyoffset');
         if (!self.S(klass).hasClass('expanded')) {
           if ($window.scrollTop() > (distance)) {
@@ -442,4 +384,4 @@
 
     reflow : function () {}
   };
-}(jQuery, window, window.document));
+}(jQuery, this, this.document));
